@@ -128,6 +128,8 @@ sinsp::sinsp() :
 	m_meinfo.m_pievt.m_fdinfo = NULL;
 	m_meinfo.m_n_procinfo_evts = 0;
 	m_meta_event_callback = NULL;
+	m_k8s_client = NULL;
+	m_k8s_last_watch_time_ns = 0;
 }
 
 sinsp::~sinsp()
@@ -167,6 +169,12 @@ sinsp::~sinsp()
 	{
 		delete[] m_meinfo.m_piscapevt;
 	}
+
+	if(m_k8s_client)
+	{
+		delete m_k8s_client;
+		m_k8s_client = NULL;
+	}
 }
 
 void sinsp::add_protodecoders()
@@ -783,6 +791,11 @@ int32_t sinsp::next(OUT sinsp_evt **puevt)
 	{
 		m_thread_manager->remove_inactive_threads();
 		m_container_manager.remove_inactive_containers();
+		
+		if(m_k8s_client)
+		{
+			update_kubernetes_state();
+		}
 	}
 #endif // HAS_ANALYZER
 
@@ -930,6 +943,9 @@ int32_t sinsp::next(OUT sinsp_evt **puevt)
 	}
 #endif
 
+	// Clean parse related event data after analyzer did its parsing too
+	m_parser->event_cleanup(evt);
+
 	//
 	// Update the last event time for this thread
 	//
@@ -1288,6 +1304,11 @@ void sinsp::set_log_file(string filename)
 	g_logger.add_file_log(filename);
 }
 
+void sinsp::set_log_stderr()
+{
+	g_logger.add_stderr_log();
+}
+
 void sinsp::set_min_log_severity(sinsp_logger::severity sev)
 {
 	g_logger.set_severity(sev);
@@ -1410,6 +1431,44 @@ bool sinsp::remove_inactive_threads()
 	return m_thread_manager->remove_inactive_threads();
 }
 
+void sinsp::init_k8s_client(const string& api_server)
+{
+	m_k8s_api_server = api_server;
+
+	if(m_k8s_client == NULL)
+	{
+		g_logger.log("Fetching initial k8s state");
+		m_k8s_client = new k8s(api_server, true);
+	}
+}
+
+void sinsp::update_kubernetes_state()
+{
+	ASSERT(m_k8s_client);
+	if(m_lastevent_ts > m_k8s_last_watch_time_ns + ONE_SECOND_IN_NS)
+	{
+		m_k8s_last_watch_time_ns = m_lastevent_ts;
+
+		if(m_k8s_client->is_alive())
+		{
+			uint64_t delta = sinsp_utils::get_current_time_ns();
+			
+			m_k8s_client->watch();
+
+			delta = sinsp_utils::get_current_time_ns() - delta;
+
+			g_logger.format(sinsp_logger::SEV_INFO, "Updating Kubernetes state took %" PRIu64 " ms", delta / 1000000LL);
+		}
+		else
+		{
+			g_logger.format(sinsp_logger::SEV_WARNING, "Kubernetes connection not active anymore, retrying");
+			delete m_k8s_client;
+			m_k8s_client = NULL;
+			init_k8s_client(m_k8s_api_server);
+		}
+	}
+}
+
 ///////////////////////////////////////////////////////////////////////////////
 // Note: this is defined here so we can inline it in sinso::next
 ///////////////////////////////////////////////////////////////////////////////
