@@ -78,6 +78,7 @@ void sinsp_threadinfo::init()
 #endif
 	m_ainfo = NULL;
 	m_program_hash = 0;
+	m_lastevent_data = NULL;
 }
 
 sinsp_threadinfo::~sinsp_threadinfo()
@@ -314,6 +315,7 @@ void sinsp_threadinfo::init(const scap_threadinfo* pi)
 	{
 		add_fd(fdi);
 	}
+	m_lastevent_data = NULL;
 }
 
 string sinsp_threadinfo::get_comm()
@@ -459,28 +461,6 @@ bool sinsp_threadinfo::uses_client_port(uint16_t number)
 	return false;
 }
 
-void sinsp_threadinfo::store_event(sinsp_evt *evt)
-{
-	uint32_t elen;
-
-	//
-	// Make sure the event data is going to fit
-	//
-	elen = scap_event_getlen(evt->m_pevt);
-
-	if(elen > SP_EVT_BUF_SIZE)
-	{
-		ASSERT(false);
-		return;
-	}
-
-	//
-	// Copy the data
-	//
-	memcpy(m_lastevent_data, evt->m_pevt, elen);
-	m_lastevent_cpuid = evt->get_cpuid();
-}
-
 bool sinsp_threadinfo::is_lastevent_data_valid()
 {
 	return (m_lastevent_cpuid != (uint16_t) - 1);
