@@ -262,7 +262,6 @@ VISIBILITY_PRIVATE
 	void set_args(const char* args, size_t len);
 	void set_env(const char* env, size_t len);
 	void set_cgroups(const char* cgroups, size_t len);
-	void store_event(sinsp_evt *evt);
 	bool is_lastevent_data_valid();
 	inline void set_lastevent_data_validity(bool isvalid)
 	{
@@ -290,7 +289,7 @@ VISIBILITY_PRIVATE
 	sinsp_fdtable m_fdtable; // The fd table of this thread
 	string m_cwd; // current working directory
 	sinsp_threadinfo* m_main_thread;
-	uint8_t m_lastevent_data[SP_EVT_BUF_SIZE]; // Used by some event parsers to store the last enter event
+	uint8_t* m_lastevent_data; // Used by some event parsers to store the last enter event
 	vector<void*> m_private_state;
 
 	uint16_t m_lastevent_type;
